@@ -87,7 +87,7 @@ class Period:
 @dataclass
 class DateParts:
     def __init__(self, time: datetime = datetime.now()):
-        self.y = str(time.year).rjust(2, '0')
+        self.y = str(time.year)
         self.m = str(time.month).rjust(2, '0')
         self.d = str(time.day).rjust(2, '0')
         self.h = str(time.hour).rjust(2, '0')
